@@ -8,6 +8,7 @@ from edc_constants.constants import (
     NEG,
     NO,
     NOT_APPLICABLE,
+    NOT_DONE,
     NOT_EVALUATED,
     PENDING,
     POS,
@@ -327,9 +328,30 @@ class TestSubjectScreeningForm(FormValidatorTestCaseMixin, TestCaseMixin, TestCa
                     str(cm.exception.error_dict.get("serum_crag_date")),
                 )
 
-    def test_serum_crag_gt_14_days_after_report_date_raises(self):
+    def test_serum_crag_lte_14_days_before_report_date_ok(self):
+        for days in [14, 13, 1, 0]:
+            with self.subTest(days_before=days):
+                cleaned_data = self.get_cleaned_data()
+                report_datetime = get_utcnow()
+                cleaned_data.update(
+                    {
+                        "report_datetime": report_datetime,
+                        "cd4_value": self.ELIGIBLE_CD4_VALUE,
+                        "cd4_date": report_datetime.date() - relativedelta(days=days),
+                        "serum_crag_value": POS,
+                        "serum_crag_date": report_datetime.date() - relativedelta(days=days),
+                        "lp_date": report_datetime.date() - relativedelta(days=days),
+                    }
+                )
+                form_validator = SubjectScreeningFormValidator(cleaned_data=cleaned_data)
+                try:
+                    form_validator.validate()
+                except ValidationError as e:
+                    self.fail(f"ValidationError unexpectedly raised. Got {e}")
+
+    def test_serum_crag_gt_14_days_before_report_date_ok(self):
         for days in [15, 20, 21]:
-            with self.subTest(days_after=days):
+            with self.subTest(days_before=days):
                 cleaned_data = self.get_cleaned_data()
                 report_datetime = get_utcnow()
                 cleaned_data.update(
@@ -342,13 +364,10 @@ class TestSubjectScreeningForm(FormValidatorTestCaseMixin, TestCaseMixin, TestCa
                     }
                 )
                 form_validator = SubjectScreeningFormValidator(cleaned_data=cleaned_data)
-                with self.assertRaises(ValidationError) as cm:
+                try:
                     form_validator.validate()
-                self.assertIn("serum_crag_date", cm.exception.error_dict)
-                self.assertIn(
-                    "Invalid. Cannot be more than 14 days before the report date",
-                    str(cm.exception.error_dict.get("serum_crag_date")),
-                )
+                except ValidationError as e:
+                    self.fail(f"ValidationError unexpectedly raised. Got {e}")
 
     def test_lp_date_gt_3_days_before_serum_crag_date_raises(self):
         for days_before in [4, 14, 21]:
@@ -458,6 +477,64 @@ class TestSubjectScreeningForm(FormValidatorTestCaseMixin, TestCaseMixin, TestCa
         except ValidationError as e:
             self.fail(f"ValidationError unexpectedly raised. Got {e}")
 
+    def test_csf_crag_value_not_applicable_if_lp_done_no(self):
+        for csf_crag_value in [POS, NEG, PENDING, NOT_DONE]:
+            with self.subTest(csf_crag_value):
+                cleaned_data = self.get_cleaned_data()
+                cleaned_data.update(
+                    {
+                        "lp_done": NO,
+                        "lp_date": None,
+                        "lp_declined": YES,
+                        "csf_crag_value": csf_crag_value,
+                    }
+                )
+                form_validator = SubjectScreeningFormValidator(cleaned_data=cleaned_data)
+                with self.assertRaises(ValidationError) as cm:
+                    form_validator.validate()
+                self.assertIn("csf_crag_value", cm.exception.error_dict)
+                self.assertIn(
+                    "This field is not applicable.",
+                    str(cm.exception.error_dict.get("csf_crag_value")),
+                )
+
+    def test_csf_crag_value_applicable_if_lp_done_yes(self):
+        cleaned_data = self.get_cleaned_data()
+        cleaned_data.update(
+            {
+                "lp_done": YES,
+                "lp_date": cleaned_data.get("report_datetime").date(),
+                "lp_declined": NOT_APPLICABLE,
+                "csf_crag_value": NOT_APPLICABLE,
+            }
+        )
+        form_validator = SubjectScreeningFormValidator(cleaned_data=cleaned_data)
+        with self.assertRaises(ValidationError) as cm:
+            form_validator.validate()
+        self.assertIn("csf_crag_value", cm.exception.error_dict)
+        self.assertIn(
+            "This field is applicable.",
+            str(cm.exception.error_dict.get("csf_crag_value")),
+        )
+
+    def test_csf_crag_value_ok_if_lp_done_yes(self):
+        for csf_crag_value in [POS, NEG, PENDING, NOT_DONE]:
+            with self.subTest(csf_crag_value=csf_crag_value):
+                cleaned_data = self.get_cleaned_data()
+                cleaned_data.update(
+                    {
+                        "lp_done": YES,
+                        "lp_date": cleaned_data.get("report_datetime").date(),
+                        "lp_declined": NOT_APPLICABLE,
+                        "csf_crag_value": csf_crag_value,
+                    }
+                )
+                form_validator = SubjectScreeningFormValidator(cleaned_data=cleaned_data)
+                try:
+                    form_validator.validate()
+                except ValidationError as e:
+                    self.fail(f"ValidationError unexpectedly raised. Got {e}")
+
     def test_cm_in_csf_date_before_lp_date_raises(self):
         for days in [1, 2, 10]:
             with self.subTest(days_before=days):
